@@ -350,9 +350,11 @@ class Database(object):
 		# arguments.
 		self.aes = aes
 		self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}/"
-		if not Files.exists(self.path[:-1]): 
-			os.mkdir(self.path)
-			os.system(f"chown {OWNER}:{GROUP} {self.path} && chmod 770 {self.path}")
+		self.file_path = self.fp = FilePath(self.path)
+		if not self.fp.exists():
+			os.system(f"mkdir {self.fp.path}")
+			self.fp.ownership.set(owner=syst3m.defaults.vars.owner)
+			self.fp.permission.set(permission=770)
 
 		# variables.
 		self.activated = False
@@ -361,14 +363,16 @@ class Database(object):
 	def activate(self):
 
 		# check sample.
+		if not Files.exists(f"{self.path}"):
+			return r3sponse.error(f"Encrypted database root [{self.path}] does not exist".)
 		if not Files.exists(f"{self.path}.passphrase"):
 			response = self.aes.encrypt(self.aes.rsa.passphrase)
 			if not response.success: return response
 			try: utils.__save_bytes__(f"{self.path}.passphrase", response.encrypted)
-			except: return r3sponse.error(f"Failed to write out encrypted passphrase {self.path}.passphrase")
+			except: return r3sponse.error(f"Failed to write out encrypted passphrase [{self.path}.passphrase]")
 		else:
 			try: passphrase = utils.__load_bytes__(f"{self.path}.passphrase")
-			except: return r3sponse.error(f"Failed to load encrypted passphrase {self.path}.passphrase")
+			except: return r3sponse.error(f"Failed to load encrypted passphrase [{self.path}.passphrase]")
 			response = self.aes.decrypt(passphrase)
 			if not response.success: return response
 			if response.decrypted.decode().replace("\n","") != self.aes.rsa.passphrase.replace("\n",""):
@@ -376,7 +380,7 @@ class Database(object):
 
 		# success.
 		self.activated = True
-		return r3sponse.success(f"Successfully activated encrypted database {self.path}.")
+		return r3sponse.success(f"Successfully activated encrypted database [{self.path}].")
 
 		#
 	def check(self, 
@@ -463,9 +467,9 @@ class Database(object):
 				if old_format != new_format:
 					return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
 				if new_format == "dict":
-					old = dict(self.content)
+					old = Dictionary(self.content)
 					new = Dictionary(path=False, dictionary=old).check(default=default, save=False)
-					if dict(new) != dict(old): do = True
+					if new != old: do = True
 				elif new_format == "list":
 					old = list(self.content)
 					new = list(default)
@@ -478,7 +482,7 @@ class Database(object):
 					if new != old: do = True
 				else: return r3sponse.error(f"Unsupported new format: {new_format}.")
 			if do:
-				self.content = new
+				self.content = Formats.denitialize(new)
 				self.format = Formats.get(self.content, serialize=True)
 				if save:
 					self.loaded = True
@@ -511,7 +515,7 @@ class Database(object):
 					content = str(decrypted)
 				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
 			else: return r3sponse.error(f"Unsupported format: {format}.")
-			self.content = content
+			self.content = Formats.denitialize(content)
 			self.format = format
 			self.loaded = True
 			return r3sponse.success(f"Successfully loaded content {self.path}.")
@@ -598,12 +602,16 @@ class Database(object):
 			if not self.loaded: raise ValueError("Load the content object first.")
 			if self.format in ["dict"]:
 				setattr(self.content, key, value)
+			elif self.format in ["str"] and isinstance(key, (int, Integer)):
+				self.content[int(key)] = value
 			else:
 				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
 		def __getitem__(self, key):
 			if not self.loaded: raise ValueError("Load the content object first.")
 			if self.format in ["dict"]:
 				return getattr(self.content, key)
+			elif self.format in ["str"] and isinstance(key, (int, Integer)):
+				return self.content[int(key)]
 			else:
 				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
 		def __delitem__(self, key):
@@ -614,6 +622,9 @@ class Database(object):
 				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
 		# string format.
 		def __str__(self):
+			return str(self.content)
+		# repr.
+		def __repr__(self):
 			if not self.loaded: 
 				return f"<encrypti0n.aes.Database.DataObject {self.path} content: not loaded yet>"
 			elif self.format in ["dict"]:
