@@ -44,7 +44,7 @@ class RSA(object):
 				self.private_key = directory+"/private_key.pem"
 				self.public_key = directory+"/public_key.pem"
 			else:
-				self.directory = Formats.FilePath(private_key).base()
+				self.directory = FilePath(private_key).base()
 				self.private_key = private_key
 				self.public_key = public_key
 				self.id = str(self.public_key)
@@ -65,7 +65,7 @@ class RSA(object):
 		# checks.
 		if not self.memory:
 			if log_level >= 0: loader = syst3m.console.Loader(f"Generating key {self.directory}")
-			if os.path.exists(directory): 
+			if Files.exists(directory): 
 				response["error"] = f"Key [{directory}] already exists."
 				return response
 		else:
@@ -84,8 +84,8 @@ class RSA(object):
 		# save.
 		if not self.memory:
 			os.mkdir(directory)
-			utils.__save_file__(private_key_path, private_key_pem.decode())
-			utils.__save_file__(public_key_path, public_key_pem.decode())
+			Files.save(private_key_path, private_key_pem.decode())
+			Files.save(public_key_path, public_key_pem.decode())
 			utils.__set_file_path_permission__(directory, permission=700)
 			utils.__set_file_path_permission__(private_key_path, permission=600)
 			utils.__set_file_path_permission__(public_key_path, permission=644)
@@ -102,8 +102,8 @@ class RSA(object):
 		# load keys.
 		response = utils.__default_response__()
 		if not self.memory:
-			self.private_key_data = utils.__load_file__(self.private_key)
-			self.public_key_data = utils.__load_file__(self.public_key)
+			self.private_key_data = Files.load(self.private_key)
+			self.public_key_data = Files.load(self.public_key)
 		else:
 			self.private_key_data = self.private_key
 			self.public_key_data = self.public_key
@@ -138,7 +138,7 @@ class RSA(object):
 		# load keys.
 		response = utils.__default_response__()
 		if not self.memory:
-			self.public_key_data = utils.__load_file__(self.public_key)
+			self.public_key_data = Files.load(self.public_key)
 		else:
 			self.public_key_data = self.public_key
 
@@ -160,7 +160,7 @@ class RSA(object):
 		# load keys.
 		response = utils.__default_response__()
 		if not self.memory:
-			self.private_key_data = utils.__load_file__(self.private_key)
+			self.private_key_data = Files.load(self.private_key)
 		else:
 			self.private_key_data = self.private_key
 
@@ -260,7 +260,7 @@ class RSA(object):
 		else:
 
 			# checks.
-			file_path = Formats.FilePath(path)
+			file_path = FilePath(path)
 			if not file_path.exists():
 				response["error"] = f"Directory [{path}] does not exist."
 				return response
@@ -272,7 +272,7 @@ class RSA(object):
 			if path[len(path)-1] == "/": zip_path = path[:-1]
 			else: zip_path = str(path)
 			zip_path = f'{zip_path}.encrypted.zip'
-			zip = Files.Zip(path=zip_path)
+			zip = Zip(path=zip_path)
 			zip.create(source=path)
 
 			# encrypt zip.
@@ -376,13 +376,13 @@ class RSA(object):
 			path = path.replace('.encrypted.zip', '/')
 
 			# checks.
-			file_path = Formats.FilePath(path)
+			file_path = FilePath(path)
 
 			# set zip path.
 			if path[len(path)-1] == "/": zip_path = path[:-1]
 			else: zip_path = str(path)
 			zip_path = f'{zip_path}.encrypted.zip'
-			if not os.path.exists(zip_path):
+			if not Files.exists(zip_path):
 				response["error"] = f"System encrypted zip [{path}] does not exist."
 				return response
 			
@@ -394,9 +394,9 @@ class RSA(object):
 
 			# extract zip.
 			response = utils.__default_response__()
-			zip = Files.Zip(path=zip_path)
+			zip = Zip(path=zip_path)
 			zip.extract(base=None)
-			if os.path.exists(path):
+			if Files.exists(path):
 				response["success"] = True
 				response["message"] = f"Successfully decrypted directory [{path}]."
 				zip.file_path.delete(forced=True)
@@ -408,6 +408,8 @@ class RSA(object):
 		#
 	# system functions.
 	def __encrypt_blob__(self, blob, public_key, silent=True):
+		blob = Formats.denitialize(blob)
+
 		#Import the Public Key and use for encryption using PKCS1_OAEP
 		rsa_key = public_key
 		rsa_key = PKCS1_OAEP.new(rsa_key)
@@ -451,6 +453,7 @@ class RSA(object):
 		#Base 64 encode the encrypted file
 		return base64.b64encode(encrypted)
 	def __decrypt_blob__(self, encrypted_blob, private_key, silent=True):
+		encrypted_blob = Formats.denitialize(encrypted_blob)
 
 		#Import the Private Key and use for decryption using PKCS1_OAEP
 		rsakey = private_key
@@ -486,7 +489,7 @@ class RSA(object):
 		return zlib.decompress(decrypted)
 
 # the encrypted dictionary class.
-class EncryptedDictionary(Files.Dictionary):
+class EncryptedDictionary(Dictionary):
 	"""
 		The saved dictionary remains encrypted while local memory contains the decrypted dict.
 		Requires already generated keys.
@@ -512,12 +515,12 @@ class EncryptedDictionary(Files.Dictionary):
 		self.default = default
 		self._load_ = load
 		self.dictionary = dictionary
-		self._dictionary_ = Files.Dictionary(
+		self._dictionary_ = Dictionary(
 			path=False, 
 			dictionary=self.dictionary, )
 
 		# the file object.
-		self._file_ = Files.File(path=path)
+		self._file_ = File(path=path)
 
 		# variables.
 		self.file_path = self._file_.file_path
